@@ -1,9 +1,16 @@
+# frozen_string_literal: true
+
 require 'recaptcha/configuration'
-require 'recaptcha/client_helper'
-require 'recaptcha/verify'
 require 'uri'
 require 'net/http'
 
+if defined?(Rails)
+  require 'recaptcha/railtie'
+else
+  require 'recaptcha/client_helper'
+  require 'recaptcha/verify'
+end
+
 module Recaptcha
   CONFIG = {
     'server_url' => 'https://www.google.com/recaptcha/api.js',
