@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'json'
 
 module Recaptcha
@@ -55,22 +57,25 @@ module Recaptcha
     end
 
     def self.skip?(env)
-      env ||= ENV['RACK_ENV'] || ENV['RAILS_ENV'] || (Rails.env if defined? Rails.env)
+      env ||= ENV['RAILS_ENV'] || ENV['RACK_ENV'] || (Rails.env if defined? Rails.env)
       Recaptcha.configuration.skip_verify_env.include? env
     end
 
     private
 
     def recaptcha_verify_via_api_call(request, recaptcha_response, options)
-      private_key = options[:private_key] || Recaptcha.configuration.private_key!
-      remote_ip = (request.respond_to?(:remote_ip) && request.remote_ip) || (env && env['REMOTE_ADDR'])
+      secret_key = options[:secret_key] || Recaptcha.configuration.secret_key!
 
       verify_hash = {
-        "secret"    => private_key,
-        "remoteip"  => remote_ip.to_s,
+        "secret"    => secret_key,
         "response"  => recaptcha_response
       }
 
+      unless options[:skip_remote_ip]
+        remoteip = (request.respond_to?(:remote_ip) && request.remote_ip) || (env && env['REMOTE_ADDR'])
+        verify_hash["remoteip"] = remoteip.to_s
+      end
+
       reply = JSON.parse(Recaptcha.get(verify_hash, options))
       reply['success'].to_s == "true" &&
         recaptcha_hostname_valid?(reply['hostname'], options[:hostname])
